@@ -109,7 +109,7 @@ pref("browser.chrome.image_icons.max_size", 1024);
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 113 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 113 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -117,7 +117,7 @@ pref("accessibility.warn_on_browsewithcaret", true);
 // unless accessibility.tabfocus is set by the user.
 pref("accessibility.tabfocus", 7);
 pref("accessibility.tabfocus_applies_to_xul", false);
-//@line 124 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 124 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -312,6 +312,8 @@ pref("capability.policy.mailnews.*.data.get", "noAccess");
 pref("capability.policy.mailnews.*.getAttribute", "noAccess");
 pref("capability.policy.mailnews.HTMLDivElement.getAttribute", "sameOrigin");
 pref("capability.policy.mailnews.*.getAttributeNS", "noAccess");
+pref("capability.policy.mailnews.*.getAttributeNode", "noAccess");
+pref("capability.policy.mailnews.*.getAttributeNodeNS", "noAccess");
 pref("capability.policy.mailnews.*.getNamedItem", "noAccess");
 pref("capability.policy.mailnews.*.getNamedItemNS", "noAccess");
 pref("capability.policy.mailnews.*.host.get", "noAccess");
@@ -325,11 +327,13 @@ pref("capability.policy.mailnews.*.protocol.get", "noAccess");
 pref("capability.policy.mailnews.*.src.get", "noAccess");
 pref("capability.policy.mailnews.*.substringData.get", "noAccess");
 pref("capability.policy.mailnews.*.text.get", "noAccess");
+pref("capability.policy.mailnews.*.textContent", "noAccess");
 pref("capability.policy.mailnews.*.title.get", "noAccess");
 pref("capability.policy.mailnews.DOMException.toString", "noAccess");
 pref("capability.policy.mailnews.HTMLAnchorElement.toString", "noAccess");
 pref("capability.policy.mailnews.HTMLDocument.domain", "noAccess");
 pref("capability.policy.mailnews.HTMLDocument.URL", "noAccess");
+pref("capability.policy.mailnews.*.documentURI", "noAccess");
 pref("capability.policy.mailnews.Location.toString", "noAccess");
 pref("capability.policy.mailnews.Range.toString", "noAccess");
 pref("capability.policy.mailnews.Window.blur", "noAccess");
@@ -487,7 +491,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 496 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 500 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -692,7 +696,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 706 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 710 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -840,7 +844,7 @@ pref("mousewheel.withmetakey.sysnumlines",true);
 
 // on platforms where scroll messages differ between horizontal scroll
 // and back/forward button events we can activate them by default
-//@line 888 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 892 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 // disable horizontal scrolling to be able to use back/forward buttons
 pref("mousewheel.horizscroll.withnokey.action",2);
 pref("mousewheel.horizscroll.withnokey.numlines",-1);
@@ -857,7 +861,7 @@ pref("mousewheel.horizscroll.withaltkey.sysnumlines",false);
 pref("mousewheel.horizscroll.withmetakey.action",2);
 pref("mousewheel.horizscroll.withmetakey.numlines",-1);
 pref("mousewheel.horizscroll.withmetakey.sysnumlines",false);
-//@line 905 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 909 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
 pref("profile.confirm_automigration",true);
 // profile.migration_behavior determines how the profiles root is set
@@ -1000,15 +1004,15 @@ pref("dom.max_script_run_time", 10);
 
 pref("svg.enabled", true);
 
-//@line 1378 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 1382 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1570 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 1574 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1759 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 1763 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1848 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 1852 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1851 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 1855 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1081,7 +1085,7 @@ pref("font.allow_double_byte_special_chars", true);
 
 // ar
 
-//@line 1924 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 1928 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.name.serif.el", "serif");
 pref("font.name.sans-serif.el", "sans-serif");
@@ -1140,7 +1144,7 @@ pref("font.name.sans-serif.zh-HK", "sans-serif");
 pref("font.name.monospace.zh-HK", "monospace");
 
 // zh-TW
-//@line 2043 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 2047 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.default.ar", "sans-serif");
 pref("font.size.variable.ar", 16);
@@ -1358,15 +1362,15 @@ pref("print.postscript.nativefont.zh-CN",          "");
 pref("print.postscript.nativefont.zh-TW",          "");
 pref("print.postscript.nativefont.zh-HK",          "");
 
-//@line 2263 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 2267 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2331 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 2335 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2357 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 2361 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2377 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 2381 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2385 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 2389 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2387 "/usr/obj/i386/seamonkey-1.1.11p1/mozilla/modules/libpref/src/init/all.js"
+//@line 2391 "/usr/obj/ports/seamonkey-1.1.14p0/mozilla/modules/libpref/src/init/all.js"
 pref("network.gnomevfs.supported-protocols", "smb:,sftp:");
